pub struct IndexCache { /* private fields */ }Implementations
Sourceimpl IndexCache
impl IndexCache
pub fn new(certs_source: CertsSource) -> Self
Sourcepub fn has_krate(&mut self, registry: &Url, name: &str) -> CargoResult<bool>
pub fn has_krate(&mut self, registry: &Url, name: &str) -> CargoResult<bool>
Determines if the specified crate exists in the crates.io index
Sourcepub fn has_krate_version(
&mut self,
registry: &Url,
name: &str,
version: &str,
) -> CargoResult<Option<bool>>
pub fn has_krate_version( &mut self, registry: &Url, name: &str, version: &str, ) -> CargoResult<Option<bool>>
Determines if the specified crate version exists in the crates.io index
pub fn update_krate(&mut self, registry: &Url, name: &str) -> CargoResult<()>
pub fn krate( &mut self, registry: &Url, name: &str, ) -> CargoResult<Option<IndexKrate>>